@@ -27,17 +27,13 @@ typedef struct {
 
 static void select_provider_cb (GtkMenuItem *item, gpointer data);
 
-static void save_log_file (GtkWidget *w, GnomeDbControl *control);
-static void view_selected_entry_cb (GtkWidget *w, GnomeDbControl *control);
+static void save_log_file (BonoboUIComponent *uic, GnomeDbControl *control, const gchar *path);
+static void view_selected_entry_cb (BonoboUIComponent *uic, GnomeDbControl *control, const gchar *path);
 
-static GnomeUIInfo log_control_toolbar[] = {
-	{ GNOME_APP_UI_ITEM, N_("Save"), N_("Save log to a disk file"),
-	  save_log_file, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
-	  GNOME_STOCK_PIXMAP_SAVE, 0, 0, NULL },
-	{ GNOME_APP_UI_ITEM, N_("View"), N_("View selected log entry"),
-	  view_selected_entry_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
-	  GNOME_STOCK_PIXMAP_BOOK_RED, 0, 0, NULL },
-	GNOMEUIINFO_END
+BonoboUIVerb log_verbs [] = {
+	BONOBO_UI_VERB ("LogSave", save_log_file),
+	BONOBO_UI_VERB ("LogView", view_selected_entry_cb),
+	BONOBO_UI_VERB_END
 };
 
 /*
@@ -94,7 +90,7 @@ select_provider_cb (GtkMenuItem *item, gpointer data)
 }
 
 static void
-save_log_file (GtkWidget *w, GnomeDbControl *control)
+save_log_file (BonoboUIComponent *uic, GnomeDbControl *control, const gchar *path)
 {
 	COMPONENTS_LogInfo* log_info;
 	
@@ -113,7 +109,7 @@ save_log_file (GtkWidget *w, GnomeDbControl *control)
 }
 
 static void
-view_selected_entry_cb (GtkWidget *w, GnomeDbControl *control)
+view_selected_entry_cb (BonoboUIComponent *uic, GnomeDbControl *control, const gchar *path)
 {
 	COMPONENTS_LogInfo* log_info;
 	
@@ -138,18 +134,9 @@ components_log_new (void)
 	log_info = g_new0(COMPONENTS_LogInfo, 1);
 	
 	log_info->file_sel = gnome_db_new_option_menu_widget();
-	gnome_db_set_widget_tooltip(log_info->file_sel,
-				    _("Use this option menu to select the provider whose "
-				      "log messages you want to see"));
 	gtk_table_attach(GTK_TABLE(logw), log_info->file_sel, 0, 4, 0, 1, GTK_FILL, GTK_FILL, 3, 3);
 	
 	log_info->viewer = gnome_db_log_viewer_new();
-	gnome_db_set_widget_tooltip(log_info->viewer,
-				    _("This is a list of all log messages for the provider "
-				      "you've selected. You can easily sort messages by "
-				      "any of the columns (but just clicking on them) as "
-				      "well as look at the messages individually, with more "
-				      "detail"));
 	gtk_widget_show(log_info->viewer);
 	fill_provider_list(GTK_OPTION_MENU(log_info->file_sel),
 	                   GNOME_DB_LOG_VIEWER(log_info->viewer));
@@ -160,8 +147,12 @@ components_log_new (void)
 
 	control = gnome_db_control_new(logw);
 	if (GNOME_DB_IS_CONTROL(control)) {
-		gnome_db_control_set_user_data(control, (gpointer) log_info);
-		gnome_db_control_set_toolbar(control, log_control_toolbar);
+		gnome_db_control_set_user_data (control, log_info);
+		gnome_db_control_set_ui (control,
+					 GNOMEDB_DATADIR,
+					 "gnomedb-com-log.xml",
+					 log_verbs,
+					 control);
 	}
 
 	return BONOBO_OBJECT(control);
