@@ -21,10 +21,10 @@
 #  define __gnome_db_control_h__
 
 #include <libgnome/gnome-defs.h>
-#include <libgnomeui/libgnomeui.h>
-#include <bonobo/bonobo-object.h>
+#include <bonobo/bonobo-xobject.h>
 #include <bonobo/bonobo-control.h>
-#include "GnomeDB.h"
+#include <bonobo/bonobo-ui-component.h>
+#include "GNOME_Database_UI.h"
 
 BEGIN_GNOME_DECLS
 
@@ -47,7 +47,7 @@ struct _GnomeDbControl {
 struct _GnomeDbControlClass {
 	BonoboXObjectClass parent_class; 
 
-	POA_GNOME_DB_Control__epv epv;
+	POA_GNOME_Database_UIControl__epv epv;
   
 	void              (*get_property)(GnomeDbControl *control, const gchar *name);
 	void              (*set_property)(GnomeDbControl *control, const gchar *name);
@@ -65,8 +65,11 @@ GtkType            gnome_db_control_get_type (void);
 GnomeDbControl*    gnome_db_control_construct (GnomeDbControl *control, GtkWidget *w);
 GnomeDbControl*    gnome_db_control_new (GtkWidget *w);
 
-void               gnome_db_control_set_menubar (GnomeDbControl *control, GnomeUIInfo *menus);
-void               gnome_db_control_set_toolbar (GnomeDbControl *control, GnomeUIInfo *toolbar);
+void               gnome_db_control_set_ui (GnomeDbControl *control,
+					    const gchar *app_prefix,
+					    const gchar *ui_xml_file,
+					    BonoboUIVerb *verbs,
+					    gpointer user_data);
 
 void               gnome_db_control_activate (GnomeDbControl *control);
 void               gnome_db_control_deactivate (GnomeDbControl *control);
